==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/DimensionsSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.InterfaceOperationSet;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.impl.InterfaceOperationSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.PropertyParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceParameterSet;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceSet;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorServiceParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorServiceSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.BridgeSet;
import io.ciera.tool.sql.ooaofooa.domain.Dimensions;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.StructureMemberSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.FunctionParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_SYNCSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.StructureMemberSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventDataItemSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.O_ATTRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.OperationParameterSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_ATTRSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.OperationParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.value.TransientVarSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.TransientVarSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.List;


public class DimensionsSetImpl extends InstanceSet<DimensionsSet,Dimensions> implements DimensionsSet {

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setSvc_ID( UniqueId ref_Svc_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setSvc_ID( ref_Svc_ID );
    }
    @Override
    public void setMember_ID( UniqueId ref_Member_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setMember_ID( ref_Member_ID );
    }
    @Override
    public void setTfr_ID( UniqueId ref_Tfr_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setTfr_ID( ref_Tfr_ID );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setPP_Id( UniqueId ref_PP_Id ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setPP_Id( ref_PP_Id );
    }
    @Override
    public void setSMedi_ID( UniqueId ref_SMedi_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setSMedi_ID( ref_SMedi_ID );
    }
    @Override
    public void setBParm_ID( UniqueId ref_BParm_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setBParm_ID( ref_BParm_ID );
    }
    @Override
    public void setSParm_ID( UniqueId ref_SParm_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setSParm_ID( ref_SParm_ID );
    }
    @Override
    public void setElementCount( int m_elementCount ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setElementCount( m_elementCount );
    }
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setSync_ID( ref_Sync_ID );
    }
    @Override
    public void setDIM_ID( UniqueId m_DIM_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setDIM_ID( m_DIM_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setBrg_ID( UniqueId ref_Brg_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setBrg_ID( ref_Brg_ID );
    }
    @Override
    public void setTSParm_ID( UniqueId ref_TSParm_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setTSParm_ID( ref_TSParm_ID );
    }
    @Override
    public void setDimensionCount( int m_dimensionCount ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setDimensionCount( m_dimensionCount );
    }
    @Override
    public void setTParm_ID( UniqueId ref_TParm_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setTParm_ID( ref_TParm_ID );
    }
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setId( ref_Id );
    }


    // selections
    @Override
    public O_ATTRSet R120_specifies_occurrences_of_O_ATTR() throws XtumlException {
        O_ATTRSet o_attrset = new O_ATTRSetImpl();
        for ( Dimensions dimensions : this ) o_attrset.add( dimensions.R120_specifies_occurrences_of_O_ATTR() );
        return o_attrset;
    }
    @Override
    public OperationParameterSet R121_specifies_occurrences_of_OperationParameter() throws XtumlException {
        OperationParameterSet operationparameterset = new OperationParameterSetImpl();
        for ( Dimensions dimensions : this ) operationparameterset.add( dimensions.R121_specifies_occurrences_of_OperationParameter() );
        return operationparameterset;
    }
    @Override
    public O_TFRSet R122_defines_return_value_dimensions_for_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( Dimensions dimensions : this ) o_tfrset.add( dimensions.R122_defines_return_value_dimensions_for_O_TFR() );
        return o_tfrset;
    }
    @Override
    public TerminatorServiceParameterSet R1655_TerminatorServiceParameter() throws XtumlException {
        TerminatorServiceParameterSet terminatorserviceparameterset = new TerminatorServiceParameterSetImpl();
        for ( Dimensions dimensions : this ) terminatorserviceparameterset.add( dimensions.R1655_TerminatorServiceParameter() );
        return terminatorserviceparameterset;
    }
    @Override
    public TerminatorServiceSet R1657_TerminatorService() throws XtumlException {
        TerminatorServiceSet terminatorserviceset = new TerminatorServiceSetImpl();
        for ( Dimensions dimensions : this ) terminatorserviceset.add( dimensions.R1657_TerminatorService() );
        return terminatorserviceset;
    }
    @Override
    public PropertyParameterSet R4017_specifies_occurrences_of_PropertyParameter() throws XtumlException {
        PropertyParameterSet propertyparameterset = new PropertyParameterSetImpl();
        for ( Dimensions dimensions : this ) propertyparameterset.add( dimensions.R4017_specifies_occurrences_of_PropertyParameter() );
        return propertyparameterset;
    }
    @Override
    public InterfaceOperationSet R4018_defines_return_value_dimensions_for__InterfaceOperation() throws XtumlException {
        InterfaceOperationSet interfaceoperationset = new InterfaceOperationSetImpl();
        for ( Dimensions dimensions : this ) interfaceoperationset.add( dimensions.R4018_defines_return_value_dimensions_for__InterfaceOperation() );
        return interfaceoperationset;
    }
    @Override
    public BridgeParameterSet R49_specifies_occurrences_of_BridgeParameter() throws XtumlException {
        BridgeParameterSet bridgeparameterset = new BridgeParameterSetImpl();
        for ( Dimensions dimensions : this ) bridgeparameterset.add( dimensions.R49_specifies_occurrences_of_BridgeParameter() );
        return bridgeparameterset;
    }
    @Override
    public BridgeSet R50_defines_return_value_dimensions_for_Bridge() throws XtumlException {
        BridgeSet bridgeset = new BridgeSetImpl();
        for ( Dimensions dimensions : this ) bridgeset.add( dimensions.R50_defines_return_value_dimensions_for_Bridge() );
        return bridgeset;
    }
    @Override
    public S_SYNCSet R51_defines_return_value_dimensions_for_S_SYNC() throws XtumlException {
        S_SYNCSet s_syncset = new S_SYNCSetImpl();
        for ( Dimensions dimensions : this ) s_syncset.add( dimensions.R51_defines_return_value_dimensions_for_S_SYNC() );
        return s_syncset;
    }
    @Override
    public FunctionParameterSet R52_specifies_occurrences_of_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( Dimensions dimensions : this ) functionparameterset.add( dimensions.R52_specifies_occurrences_of_FunctionParameter() );
        return functionparameterset;
    }
    @Override
    public StateMachineEventDataItemSet R531_specifies_occurrences_of_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( Dimensions dimensions : this ) statemachineeventdataitemset.add( dimensions.R531_specifies_occurrences_of_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }
    @Override
    public StructureMemberSet R53_specifies_occurrences_of_StructureMember() throws XtumlException {
        StructureMemberSet structurememberset = new StructureMemberSetImpl();
        for ( Dimensions dimensions : this ) structurememberset.add( dimensions.R53_specifies_occurrences_of_StructureMember() );
        return structurememberset;
    }
    @Override
    public TransientVarSet R844_specifies_occurrences_of_TransientVar() throws XtumlException {
        TransientVarSet transientvarset = new TransientVarSetImpl();
        for ( Dimensions dimensions : this ) transientvarset.add( dimensions.R844_specifies_occurrences_of_TransientVar() );
        return transientvarset;
    }
    @Override
    public V_VARSet R849_specifies_occurrences_of_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( Dimensions dimensions : this ) v_varset.add( dimensions.R849_specifies_occurrences_of_V_VAR() );
        return v_varset;
    }


    @Override
    public Dimensions nullElement() {
        return DimensionsImpl.EMPTY_DIMENSIONS;
    }

    @Override
    public DimensionsSet emptySet() {
      return new DimensionsSetImpl();
    }

    @Override
    public DimensionsSet value() {
        return this;
    }

    @Override
    public List<Dimensions> elements() {
        return Arrays.asList(toArray(new Dimensions[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/DimensionsSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.InterfaceOperationSet;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.impl.InterfaceOperationSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.PropertyParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceParameterSet;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceSet;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorServiceParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorServiceSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.BridgeSet;
import io.ciera.tool.sql.ooaofooa.domain.Dimensions;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.StructureMemberSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.FunctionParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_SYNCSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.StructureMemberSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventDataItemSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.O_ATTRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.OperationParameterSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_ATTRSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.OperationParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.value.TransientVarSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.TransientVarSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class DimensionsSetImpl extends InstanceSet<DimensionsSet,Dimensions> implements DimensionsSet {

    public DimensionsSetImpl() {
    }

    public DimensionsSetImpl(Comparator<? super Dimensions> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setPP_Id( UniqueId ref_PP_Id ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setPP_Id( ref_PP_Id );
    }
    @Override
    public void setBrg_ID( UniqueId ref_Brg_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setBrg_ID( ref_Brg_ID );
    }
    @Override
    public void setTfr_ID( UniqueId ref_Tfr_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setTfr_ID( ref_Tfr_ID );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setMember_ID( UniqueId ref_Member_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setMember_ID( ref_Member_ID );
    }
    @Override
    public void setSMedi_ID( UniqueId ref_SMedi_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setSMedi_ID( ref_SMedi_ID );
    }
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setDIM_ID( UniqueId m_DIM_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setDIM_ID( m_DIM_ID );
    }
    @Override
    public void setTSParm_ID( UniqueId ref_TSParm_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setTSParm_ID( ref_TSParm_ID );
    }
    @Override
    public void setSvc_ID( UniqueId ref_Svc_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setSvc_ID( ref_Svc_ID );
    }
    @Override
    public void setDimensionCount( int m_dimensionCount ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setDimensionCount( m_dimensionCount );
    }
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setSync_ID( ref_Sync_ID );
    }
    @Override
    public void setElementCount( int m_elementCount ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setElementCount( m_elementCount );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setId( ref_Id );
    }
    @Override
    public void setBParm_ID( UniqueId ref_BParm_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setBParm_ID( ref_BParm_ID );
    }
    @Override
    public void setTParm_ID( UniqueId ref_TParm_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setTParm_ID( ref_TParm_ID );
    }
    @Override
    public void setSParm_ID( UniqueId ref_SParm_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setSParm_ID( ref_SParm_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( Dimensions dimensions : this ) dimensions.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public O_ATTRSet R120_specifies_occurrences_of_O_ATTR() throws XtumlException {
        O_ATTRSet o_attrset = new O_ATTRSetImpl();
        for ( Dimensions dimensions : this ) o_attrset.add( dimensions.R120_specifies_occurrences_of_O_ATTR() );
        return o_attrset;
    }
    @Override
    public OperationParameterSet R121_specifies_occurrences_of_OperationParameter() throws XtumlException {
        OperationParameterSet operationparameterset = new OperationParameterSetImpl();
        for ( Dimensions dimensions : this ) operationparameterset.add( dimensions.R121_specifies_occurrences_of_OperationParameter() );
        return operationparameterset;
    }
    @Override
    public O_TFRSet R122_defines_return_value_dimensions_for_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( Dimensions dimensions : this ) o_tfrset.add( dimensions.R122_defines_return_value_dimensions_for_O_TFR() );
        return o_tfrset;
    }
    @Override
    public TerminatorServiceParameterSet R1655_TerminatorServiceParameter() throws XtumlException {
        TerminatorServiceParameterSet terminatorserviceparameterset = new TerminatorServiceParameterSetImpl();
        for ( Dimensions dimensions : this ) terminatorserviceparameterset.add( dimensions.R1655_TerminatorServiceParameter() );
        return terminatorserviceparameterset;
    }
    @Override
    public TerminatorServiceSet R1657_TerminatorService() throws XtumlException {
        TerminatorServiceSet terminatorserviceset = new TerminatorServiceSetImpl();
        for ( Dimensions dimensions : this ) terminatorserviceset.add( dimensions.R1657_TerminatorService() );
        return terminatorserviceset;
    }
    @Override
    public PropertyParameterSet R4017_specifies_occurrences_of_PropertyParameter() throws XtumlException {
        PropertyParameterSet propertyparameterset = new PropertyParameterSetImpl();
        for ( Dimensions dimensions : this ) propertyparameterset.add( dimensions.R4017_specifies_occurrences_of_PropertyParameter() );
        return propertyparameterset;
    }
    @Override
    public InterfaceOperationSet R4018_defines_return_value_dimensions_for__InterfaceOperation() throws XtumlException {
        InterfaceOperationSet interfaceoperationset = new InterfaceOperationSetImpl();
        for ( Dimensions dimensions : this ) interfaceoperationset.add( dimensions.R4018_defines_return_value_dimensions_for__InterfaceOperation() );
        return interfaceoperationset;
    }
    @Override
    public BridgeParameterSet R49_specifies_occurrences_of_BridgeParameter() throws XtumlException {
        BridgeParameterSet bridgeparameterset = new BridgeParameterSetImpl();
        for ( Dimensions dimensions : this ) bridgeparameterset.add( dimensions.R49_specifies_occurrences_of_BridgeParameter() );
        return bridgeparameterset;
    }
    @Override
    public BridgeSet R50_defines_return_value_dimensions_for_Bridge() throws XtumlException {
        BridgeSet bridgeset = new BridgeSetImpl();
        for ( Dimensions dimensions : this ) bridgeset.add( dimensions.R50_defines_return_value_dimensions_for_Bridge() );
        return bridgeset;
    }
    @Override
    public S_SYNCSet R51_defines_return_value_dimensions_for_S_SYNC() throws XtumlException {
        S_SYNCSet s_syncset = new S_SYNCSetImpl();
        for ( Dimensions dimensions : this ) s_syncset.add( dimensions.R51_defines_return_value_dimensions_for_S_SYNC() );
        return s_syncset;
    }
    @Override
    public FunctionParameterSet R52_specifies_occurrences_of_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( Dimensions dimensions : this ) functionparameterset.add( dimensions.R52_specifies_occurrences_of_FunctionParameter() );
        return functionparameterset;
    }
    @Override
    public StateMachineEventDataItemSet R531_specifies_occurrences_of_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( Dimensions dimensions : this ) statemachineeventdataitemset.add( dimensions.R531_specifies_occurrences_of_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }
    @Override
    public StructureMemberSet R53_specifies_occurrences_of_StructureMember() throws XtumlException {
        StructureMemberSet structurememberset = new StructureMemberSetImpl();
        for ( Dimensions dimensions : this ) structurememberset.add( dimensions.R53_specifies_occurrences_of_StructureMember() );
        return structurememberset;
    }
    @Override
    public TransientVarSet R844_specifies_occurrences_of_TransientVar() throws XtumlException {
        TransientVarSet transientvarset = new TransientVarSetImpl();
        for ( Dimensions dimensions : this ) transientvarset.add( dimensions.R844_specifies_occurrences_of_TransientVar() );
        return transientvarset;
    }
    @Override
    public V_VARSet R849_specifies_occurrences_of_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( Dimensions dimensions : this ) v_varset.add( dimensions.R849_specifies_occurrences_of_V_VAR() );
        return v_varset;
    }


    @Override
    public Dimensions nullElement() {
        return DimensionsImpl.EMPTY_DIMENSIONS;
    }

    @Override
    public DimensionsSet emptySet() {
      return new DimensionsSetImpl();
    }

    @Override
    public DimensionsSet emptySet(Comparator<? super Dimensions> comp) {
      return new DimensionsSetImpl(comp);
    }

    @Override
    public DimensionsSet value() {
        return this;
    }

    @Override
    public List<Dimensions> elements() {
        return Arrays.asList(toArray(new Dimensions[0]));
    }

}
